componenttools.ContainmentSignature
===================================

.. inheritance-diagram:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature
   :private-bases:

.. autoclass:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__eq__

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__ne__

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__repr__

.. automethod:: abjad.tools.componenttools.ContainmentSignature.ContainmentSignature.ContainmentSignature.__str__
